Package: MLE
Type: Package
Title: Maximum Likelihood Estimation of Various Univariate and
        Multivariate Distributions
Version: 1.7
Date: 2026-03-27
Authors@R: c( person("Michail", "Tsagris", role = c("aut", "cre"), email = "mtsagris@uoc.gr"), 
              person("Sofia", "Piperaki", role = c("aut"), email = "sofiapip23@gmail.com"),
              person( "Muhammad", "Imran", role = "ctb", email = "imranshakoor84@yahoo.com" ),
              person( "Rafail", "Vargiakakis", role = "aut", email = "rafailvargiakakis@gmail.com" ),
              person( "Nikolaos", "Kontemeniotis", role = "aut", email = "kontemeniotisn@gmail.com" ) )
Author: Michail Tsagris [aut, cre],
  Sofia Piperaki [aut],
  Muhammad Imran [ctb],
  Rafail Vargiakakis [aut],
  Nikolaos Kontemeniotis [aut]
Maintainer: Michail Tsagris <mtsagris@uoc.gr>
Depends: R (>= 4.0)
Imports: BGFD, bivpois, CCd, COMPoissonReg, Compositional, Directional,
        foldedt, geppe, gp, MN, Rfast, Rfast2
Suggests: mvcauchy, rangen
Description: Several functions for maximum likelihood estimation of various univariate and multivariate distributions. The list includes more than 100 functions for univariate continuous and discrete distributions, distributions that lie on the real line, the positive line, interval restricted, circular distributions. Further, multivariate continuous and discrete distributions, distributions for compositional and directional data, etc. Some references include Johnson N. L., Kotz S. and Balakrishnan N. (1994). "Continuous Univariate Distributions, Volume 1" <ISBN:978-0-471-58495-7>, Johnson, Norman L. Kemp, Adrianne W. Kotz, Samuel (2005). "Univariate Discrete Distributions". <ISBN:978-0-471-71580-1> and Mardia, K. V. and Jupp, P. E. (2000). "Directional Statistics". <ISBN:978-0-471-95333-3>. 
License: GPL (>= 2)
NeedsCompilation: no
Packaged: 2026-03-27 09:27:13 UTC; mtsag
Repository: CRAN
Date/Publication: 2026-03-27 16:20:02 UTC
Built: R 4.6.0; ; 2026-04-26 19:48:48 UTC; unix
