#useDynLib(fsn, .registration = TRUE)

importFrom("BGFD", mBellB, mBellBX, mBellE, mBellEW, mBellEE, mBellF, mBellL,
           mBellW, mCBellB, mCBellBX, mCBellE, mCBellEW, mCBellEE, mCBellF,
           mCBellL, mCBellW)
importFrom("bivpois", bp.mle, bp.mle2)
importFrom("CCd", cc.mle, cc.mle0)
importFrom("COMPoissonReg", glm.cmp)
importFrom("Compositional", zad.est, alpha.mle, a.est)

importFrom("Directional", spcauchy.mle, spcauchy.mle2, sipc.mle, pkbd.mle,
           kent.mle, esag.mle, sespc.mle, wood.mle, circexp.mle, circbeta.mle,
           cardio.mle, ggvm.mle, cipc.mle, gcpc.mle, mmvm.mle, matrixfisher.mle)

importFrom("geppe", epois.mle, gep.mle, pe.mle)
importFrom("gp", gp.mle)
importFrom("MN", mn.mle)
importFrom("foldedt", halft.mle, halft1.mle, foldedt.mle)

importFrom("Rfast", tobit.mle, vm.mle, spml.mle, wrapcauchy.mle, colvm.mle,
           colpoisson.mle, colgeom.mle, colgammamle, colweibull.mle,
           colpareto.mle, colexpmle, colexp2.mle, colmaxboltz.mle,
           collindley.mle, colrayleigh.mle, colnormlog.mle, colinvgauss.mle,
           colnormal.mle, collaplace.mle, diri.nr2, poisson.mle, zip.mle,
           ztp.mle, negbin.mle, binom.mle, borel.mle, geom.mle, logseries.mle,
           betageom.mle, betabinom.mle, vmf.mle, multivmf.mle, acg.mle, iag.mle,
           mvnorm.mle, mvlnorm.mle, mvt.mle, invdir.mle, multinom.mle,
           dirimultinom.mle, ordinal.mle, gammamle, chisq.mle, weibull.mle,
           lomax.mle, foldnorm.mle, betaprime.mle, lognorm.mle, logcauchy.mle,
           loglogistic.mle, normlog.mle, halfnorm.mle, invgauss.mle, pareto.mle,
           expmle, exp2.mle, maxboltz.mle, rayleigh.mle, lindley.mle, beta.mle,
           ibeta.mle, logitnorm.mle, hsecant01.mle, normal.mle, gumbel.mle,
           cauchy.mle, logistic.mle, ct.mle, tmle, wigner.mle, laplace.mle)

importFrom("Rfast2", censweibull.mle, censpois.mle, colcensweibull.mle,
           colcenspois.mle, colspml.mle, colborel.mle, colordinal.mle,
           collognorm.mle, colhalfnorm.mle, colbeta.mle, collogitnorm.mle,
           colcauchy.mle, colpowerlaw.mle, colunitweibull.mle, colsp.mle,
           purka.mle, halfcauchy.mle, powerlaw.mle, gammapois.mle,
           multivm.mle, multispml.mle, zigamma.mle, ziweibull.mle, cauchy0.mle,
           gnormal0.mle, trunccauchy.mle, truncexpmle, kumar.mle, simplex.mle,
           zil.mle, unitweibull.mle, cbern.mle, sp.mle)

importFrom("stats", optim, optimise)

exportPattern("^[[:alpha:]]+")
exportPattern("^[^\\.]")
